==> aliyun-python-sdk-companyreg-1.2.1.tar.gz: aliyun-python-sdk-companyreg-1.2.1/aliyunsdkcompanyreg/request/v20201022/ScanInvoiceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcompanyreg.endpoint import endpoint_data

class ScanInvoiceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'ScanInvoice')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Date(self):
		return self.get_query_params().get('Date')

	def set_Date(self,Date):
		self.add_query_param('Date',Date)

	def get_No(self):
		return self.get_query_params().get('No')

	def set_No(self,No):
		self.add_query_param('No',No)

	def get_Amount(self):
		return self.get_query_params().get('Amount')

	def set_Amount(self,Amount):
		self.add_query_param('Amount',Amount)

	def get_Code(self):
		return self.get_query_params().get('Code')

	def set_Code(self,Code):
		self.add_query_param('Code',Code)

	def get_VCode(self):
		return self.get_query_params().get('VCode')

	def set_VCode(self,VCode):
		self.add_query_param('VCode',VCode)

	def get_BizId(self):
		return self.get_query_params().get('BizId')

	def set_BizId(self,BizId):
		self.add_query_param('BizId',BizId)

	def get_InvoiceCode(self):
		return self.get_query_params().get('InvoiceCode')

	def set_InvoiceCode(self,InvoiceCode):
		self.add_query_param('InvoiceCode',InvoiceCode)

==> aliyun-python-sdk-companyreg-2.2.2.tar.gz: aliyun-python-sdk-companyreg-2.2.2/aliyunsdkcompanyreg/request/v20201022/ScanInvoiceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcompanyreg.endpoint import endpoint_data

class ScanInvoiceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'ScanInvoice')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Date(self): # String
		return self.get_query_params().get('Date')

	def set_Date(self, Date):  # String
		self.add_query_param('Date', Date)
	def get_No(self): # String
		return self.get_query_params().get('No')

	def set_No(self, No):  # String
		self.add_query_param('No', No)
	def get_Amount(self): # String
		return self.get_query_params().get('Amount')

	def set_Amount(self, Amount):  # String
		self.add_query_param('Amount', Amount)
	def get_Code(self): # String
		return self.get_query_params().get('Code')

	def set_Code(self, Code):  # String
		self.add_query_param('Code', Code)
	def get_VCode(self): # String
		return self.get_query_params().get('VCode')

	def set_VCode(self, VCode):  # String
		self.add_query_param('VCode', VCode)
	def get_BizId(self): # String
		return self.get_query_params().get('BizId')

	def set_BizId(self, BizId):  # String
		self.add_query_param('BizId', BizId)
	def get_InvoiceCode(self): # String
		return self.get_query_params().get('InvoiceCode')

	def set_InvoiceCode(self, InvoiceCode):  # String
		self.add_query_param('InvoiceCode', InvoiceCode)
